@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2014 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    Release 2.8.x SVN: $Id$
+ * @version    Release 2.9.x SVN: $Id$
  * @link       http://www.magic3.org
  */
 if (defined("M3_SYSTEM_DEFINE_INCLUDED")) return;
@@ -48,8 +48,8 @@ define('M3_ENCODING',	'UTF-8');	// 内部エンコーディング
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'2.8.19');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2014/6/9');	// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'2.9.0');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2014/7/7');	// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms and web communication platform.');		// システムの説明
 define('M3_SYSTEM_MIN_MEMORY',		'16M');			// 最小メモリ使用量
@@ -97,6 +97,9 @@ define('M3_TAG_MACRO_USER_KEY',		'USER_');								// ユーザ定義置換キー
 define('M3_TAG_MACRO_ITEM',			'ITEM');								// 項目置換キー
 define('M3_TAG_MACRO_TITLE',		'TITLE');								// タイトル置換キー
 define('M3_TAG_MACRO_BODY',			'BODY');								// 本文置換キー
+define('M3_TAG_MACRO_DATE',			'DATE');								// 日付置換キー
+define('M3_TAG_MACRO_MESSAGE',		'MESSAGE');								// メッセージ置換キー
+define('M3_TAG_MACRO_MARK',			'MARK');								// マーク置換キー
 define('M3_TAG_MACRO_AVATAR',		'AVATAR');								// アバター置換キー
 define('M3_TAG_MACRO_URL',			'URL');									// URL置換キー
 define('M3_TAG_MACRO_FILES',		'FILES');								// 添付ファイル置換キー
@@ -140,10 +143,24 @@ define('M3_TAG_MACRO_COMMENT_DATE',			'CM_DATE');						// コメント置換キ
 define('M3_TAG_MACRO_COMMENT_TIME',			'CM_TIME');						// コメント置換キー(登録時)
 define('M3_TAG_MACRO_COMMENT_AUTHOR',		'CM_AUTHOR');					// コメント置換キー(著者)
 
+// イベントフックタイプ
+define('M3_EVENT_HOOK_TYPE_OPELOG',			'opelog');						// 運用ログ
+// イベントフック用パラメータ
+define('M3_EVENT_HOOK_PARAM_CONTENT_TYPE',	'content_type');				// コンテンツタイプ
+define('M3_EVENT_HOOK_PARAM_CONTENT_ID',	'content_id');					// コンテンツID
+define('M3_EVENT_HOOK_PARAM_UPDATE_DT',		'update_dt');					// 更新日時
+
 // データ作成用
 define('M3_WIDGET_ID_SEPARATOR',	',');									// ウィジェットIDと付加情報を連結
 define('M3_LANG_SEPARATOR',			'|');									// 言語IDと内容を連結
 
+// テンプレートタイプ
+define('M3_TEMPLATE_JOOMLA_10',			0);		// Joomla!v1.0テンプレート
+define('M3_TEMPLATE_JOOMLA_15',			1);		// Joomla!v1.5テンプレート
+define('M3_TEMPLATE_JOOMLA_25',			2);		// Joomla!v2.5テンプレート
+define('M3_TEMPLATE_BOOTSTRAP_30',		10);		// Bootstrap v3.0テンプレート
+define('M3_TEMPLATE_JQUERY_MOBILE_10',	20);		// jQuery Mobile v1.0テンプレート
+
 // 描画出力タイプ
 define('M3_RENDER_JOOMLA_OLD',		'joomla_old');		// Joomla! 1.0テンプレート
 define('M3_RENDER_JOOMLA_NEW',		'joomla_new');		// Joomla! 1.5以上のテンプレート
@@ -172,6 +189,7 @@ define('M3_VIEW_FORMAT_TIME',			'H:i:s');			// 時間
 // 表示データタイプ
 define('M3_VIEW_TYPE_DASHBOARD',	'dboard');				// ダッシュボード
 define('M3_VIEW_TYPE_SEARCH',		'search');				// 検索結果
+define('M3_VIEW_TYPE_NEWS',			'news');				// 新着情報
 define('M3_VIEW_TYPE_COMMERCE',		'commerce');			// Eコマース
 define('M3_VIEW_TYPE_CONTENT',		'content');				// 汎用コンテンツ
 define('M3_VIEW_TYPE_PRODUCT',		'product');				// 商品情報
