@@ -178,22 +178,6 @@ INSERT INTO _templates
 ('_admin3',                       '_admin3',                       2,       0,              false,     false,        0,             now()),
 ('_system',                       '_system',                       1,       0,              false,     false,        0,             now()),
 ('_layout',                       '_layout',                       1,       0,              false,     false,        0,             now()),
-('magic3_demo3',                  'magic3_demo3',                  1,       0,              false,     true,         0,             now()),
-('tft0006j_back_to_nature',       'tft0006j_back_to_nature',       1,       0,              false,     true,         1,             now()),
-('pwc007_music',                  'pwc007_music',                  1,       0,              false,     true,         1,             now()),
-('techline_de_template-j15-dog1', 'techline_de_template-j15-dog1', 1,       0,              false,     true,         1,             now()),
-('FishNew',                       'FishNew',                       1,       0,              false,     true,         1,             now()),
-('webstyles_flowers',             'webstyles_flowers',             1,       0,              false,     true,         1,             now()),
-('moyoo_blue_dog',                'moyoo_blue_dog',                1,       0,              false,     true,         0,             now()),
-('moyoo_lane_street',             'moyoo_lane_street',             1,       0,              false,     true,         0,             now()),
-('I_dive',                        'I_dive',                        1,       0,              false,     true,         0,             now()),
-('123wd-j15-3',                   '123wd-j15-3',                   1,       0,              false,     true,         0,             now()),
-('yoga_v1',                       'yoga_v1',                       1,       0,              false,     true,         0,             now()),
-('car_city_v1',                   'car_city_v1',                   1,       0,              false,     true,         0,             now()),
-('art26_test1',                   'art26_test1',                   1,       0,              false,     true,         0,             now()),
-('art26_test2',                   'art26_test2',                   1,       0,              false,     true,         0,             now()),
-('art30rc1_sample1',              'art30rc1_sample1',              1,       0,              false,     true,         0,             now()),
-('art30_041_sample2',             'art30_041_sample2',             1,       0,              false,     true,         0,             now()),
 ('art41_sample1',                 'art41_sample1',                 2,       0,              false,     true,         0,             now()),
 ('art41_sample2',                 'art41_sample2',                 2,       0,              false,     true,         0,             now()),
 ('m/default',                     'm/default',                     0,       1,              true,      true,         0,             now()),
