@@ -120,9 +120,8 @@ CKEDITOR.editorConfig = function( config ) {
 	
 	// ツールバーの設定
 	config.toolbar_Full = [
-		{ name: 'tools', items: [ 'Maximize', 'ShowBlocks' ] },
-		{ name: 'document', items: [ 'Source', 'Templates' ] },
-		{ name: 'clipboard', items: [ 'Cut', 'Copy', 'Paste', 'PasteText', 'PasteFromWord', '-', 'Undo', 'Redo' ] },
+		{ name: 'tools', items: [ 'Maximize', 'ShowBlocks', 'Source' ] },
+		{ name: 'clipboard', items: [ 'Templates', '-', 'Cut', 'Copy', 'Paste', 'PasteText', 'PasteFromWord', '-', 'Undo', 'Redo' ] },
 		{ name: 'editing', items : [ 'Find','Replace','-','SelectAll' ] },
 		{ name: 'insert', items: [ 'Image', 'Flash', 'YouTube', 'Googlemaps', 'Table', 'HorizontalRule' ] },
 		{ name: 'colors', items : [ 'TextColor', 'BGColor' ] },
@@ -145,7 +144,7 @@ CKEDITOR.editorConfig = function( config ) {
 	config.stylesCombo_stylesSet = 'default';
 	
 	// メッセージの変更
-	config.image_previewText = '<strong>「サーバーブラウザー」ボタン</strong>をクリックすると画像ブラウザが立ち上がり、サムネール表示の画像をダブルクリックすると取得できます。画像をアップロードするには、画像ブラウザ上部の「アップロード」ボタンをクリックするか、画像ブラウザ上へ画像ファイルをドロップします。';
+	config.image_previewText = '<strong>「サーバブラウザ」ボタン</strong>をクリックすると画像ブラウザが立ち上がります。サムネール表示の画像をダブルクリックすると画像が取得できます。画像をアップロードするには、画像ブラウザ上部の「アップロード」ボタンをクリックするか、画像ブラウザ上へ画像ファイルをドロップします。';
 	
 	// 追加プラグインの設定
 	config.extraPlugins = 'youtube,googlemaps,linkinfo';
