@@ -483,7 +483,7 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 			$infoSrc = file_get_contents(self::NEW_INFO_URL);
 
 			// ウィジェットIDとバージョン番号を取得して登録
-			$exp = '/^\(\'([a-zA-Z0-9_\-\/]+)\'.*\'([0-9\.]+[a-z]*)\'/m';			// バージョン番号の最後の「b」(ベータ版)等は許可
+			$exp = '/^\(\'([a-zA-Z0-9_\-\/]+)\'.*?\'([0-9\.]+[a-z]*)\'/m';			// バージョン番号の最後の「b」(ベータ版)等は許可
 	        $dest = preg_replace_callback($exp, array($this, '_update_widget_info_callback'), $infoSrc);
 			
 			$this->setMsg(self::MSG_GUIDANCE, $this->_('Latest widget information gotten.'));		// 最新のウィジェット情報を取得しました
@@ -499,11 +499,11 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 			$infoSrc = file_get_contents(self::NEW_INFO_URL);
 
 			// ウィジェットIDとバージョン番号を取得して登録
-			$exp = '/^\(\'' . preg_quote($widgetId, '/') . '\'.*\'([0-9\.]+[a-z]*)\'/m';			// バージョン番号の最後の「b」(ベータ版)等は許可
+			$exp = '/^\(\'' . preg_quote($widgetId, '/') . '\'.*?\'([0-9\.]+[a-z]*)\'/m';			// バージョン番号の最後の「b」(ベータ版)等は許可
 			if (preg_match($exp, $infoSrc, $matches)){
 				$latestVersion = $matches[1];
 				
-				if (!empty($version) && !empty($latestVersion) && version_compare($version, $latestVersion) == -1) $canUpdate = true;		// 最新バージョンが現在のバージョンよりも上の場合
+				if (!empty($version) && !empty($latestVersion) && version_compare($version, $latestVersion) < 0) $canUpdate = true;		// 最新バージョンが現在のバージョンよりも上の場合
 			}
 			if ($canUpdate){
 				// GitHubからソースコードを取得
@@ -801,7 +801,8 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 	{
 		$version = $fetchedRow['wd_version'];
 		$latestVersion = $fetchedRow['wd_latest_version'];
-		
+		$requiredVersion = $fetchedRow['wd_required_version'];		// 動作に必要なシステムバージョン
+
 		// ウィジェットが存在するかどうかチェック
 		$isExistsWidget = false;
 		$widgetId = $fetchedRow['wd_id'];// ウィジェットID
@@ -883,10 +884,15 @@ class admin_mainWidgetlistWidgetContainer extends admin_mainBaseWidgetContainer
 		$latestVer = '';
 		$regex = '/([0-9\.]+)([a-z]*)/';
 		if (preg_match($regex, $latestVersion, $matches)){
-			if (version_compare($version, $latestVersion) == -1){		// 最新バージョンが現在のバージョンよりも上の場合のみ表示
+			if (version_compare($version, $latestVersion) < 0){		// 最新バージョンが現在のバージョンよりも上の場合のみ表示
 				$optionVerStr = strtolower($matches[2]);
 				if (empty($optionVerStr)){		// 付加記号なしの場合
-					$latestVer = '<span class="available"><a href="javascript:void(0);" onclick="updateWidget(\'' . $widgetId . '\');">' . $this->convertToDispString($latestVersion) . '</a></span>';
+					// 動作に必要なシステムバージョン以上の場合のみバージョンアップ可能
+					if (version_compare($requiredVersion, M3_SYSTEM_VERSION) <= 0){
+						$latestVer = '<span class="available"><a href="javascript:void(0);" onclick="updateWidget(\'' . $widgetId . '\');">' . $this->convertToDispString($latestVersion) . '</a></span>';
+					} else {
+						$latestVer = '<span class="available">' . $this->convertToDispString($latestVersion) . '</span>';
+					}
 				} else {
 					switch ($optionVerStr){
 						case 'x':		// 緊急バージョンアップ
