@@ -19,6 +19,7 @@ require_once($gEnvManager->getCurrentWidgetDbPath() . '/default_menuDb.php');
 class default_menuWidgetContainer extends BaseWidgetContainer
 {
 	private $db;			// DB接続オブジェクト
+	private $targetObj;		// 設定オブジェクト
 	private $langId;		// 現在の言語
 	private $paramObj;		// 定義取得用
 	private $cssFilePath = array();			// CSSファイル
@@ -42,6 +43,13 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 		
 		// DBオブジェクト作成
 		$this->db = new default_menuDb();
+		
+		// 定義ID取得
+		$configId = $this->gEnv->getCurrentWidgetConfigId();
+		if (empty($configId)) $configId = self::DEFAULT_CONFIG_ID;
+		
+		// パラメータオブジェクトを取得
+		$this->targetObj = $this->getWidgetParamObjByConfigId($configId);
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -58,13 +66,24 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 		$this->renderType = 'JOOMLA_NEW';		// 描画出力タイプ
 		$this->templateType = $this->gEnv->getCurrentTemplateType();
 		$isNav = $this->isNavigationMenuStyle();		// ナビゲーションメニュータイプかどうか
+		$useVerticalMenu 	= 0;// 縦型メニューデザインを使用するかどうか
+		if (!empty($this->targetObj) && !empty($this->targetObj->useVerticalMenu)) $useVerticalMenu = 1;
 		
+		// 描画タイプを決める
 		switch ($this->templateType){
 			case 0:
 				$this->renderType = 'JOOMLA_OLD';
 				break;
 			case 10:
-				if ($isNav) $this->renderType = 'BOOTSTRAP';
+				if ($isNav){
+					$this->renderType = 'BOOTSTRAP_NAV';		// Boostrapナビゲーションメニュー
+				} else {
+					if ($useVerticalMenu){		// 縦型メニューの場合
+						$this->renderType = 'BOOTSTRAP';
+					} else {
+						$this->renderType = 'JOOMLA_NEW';		// 描画出力タイプ
+					}
+				}
 				break;
 			default:
 				$this->renderType = 'JOOMLA_NEW';		// 描画出力タイプ
@@ -80,10 +99,13 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 			case 'JOOMLA_OLD':
 				$templateFile = 'index_old.tmpl.html';
 				break;
-			case 'BOOTSTRAP':
+			case 'BOOTSTRAP_NAV':		// Bootstrapナビゲーションメニュー
 				$this->cssFilePath[] = $this->getUrl($this->gEnv->getCurrentWidgetCssUrl() . self::DEFAULT_BOOTSTRAP_CSS_FILE);		// CSSファイル
+				$templateFile = 'index_bootstrap_nav.tmpl.html';
+				break;
+			case 'BOOTSTRAP':		// Bootstrapメニュー
 				$templateFile = 'index_bootstrap.tmpl.html';
-				break;				
+				break;
 		}
 		return $templateFile;
 	}
@@ -101,12 +123,13 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 		$this->langId = $this->gEnv->getCurrentLanguage();
 		$this->currentUserLogined = $this->gEnv->isCurrentUserLogined();	// 現在のユーザはログイン中かどうか
 		
-		// 定義ID取得
-		$configId = $this->gEnv->getCurrentWidgetConfigId();
-		if (empty($configId)) $configId = self::DEFAULT_CONFIG_ID;
-		
-		// パラメータオブジェクトを取得
-		$targetObj = $this->getWidgetParamObjByConfigId($configId);
+//		// 定義ID取得
+//		$configId = $this->gEnv->getCurrentWidgetConfigId();
+//		if (empty($configId)) $configId = self::DEFAULT_CONFIG_ID;
+//		
+//		// パラメータオブジェクトを取得
+//		$targetObj = $this->getWidgetParamObjByConfigId($configId);
+		$targetObj = $this->targetObj;
 		if (empty($targetObj)){		// 定義データが取得できないとき
 			// 出力抑止
 			$this->cancelParse();
@@ -118,6 +141,9 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 		$this->isHierMenu	= $targetObj->isHierMenu;		// 階層化メニューを使用するかどうか
 		$limitUser			= $targetObj->limitUser;// ユーザを制限するかどうか
 		$useVerticalMenu 	= $targetObj->useVerticalMenu;		// 縦型メニューデザインを使用するかどうか
+		$showSitename	= isset($targetObj->showSitename) ? $targetObj->showSitename : 1;		// サイト名を表示するかどうか
+		$showSearch		= isset($targetObj->showSearch) ? $targetObj->showSearch : 0;			// 検索フィールドを表示するかどうか
+		$anotherColor	= isset($targetObj->anotherColor) ? $targetObj->anotherColor : 0;		// 色を変更するかどうか
 		
 		// 縦型メニューデザイン使用の場合はJoomla用パラメータを設定
 		if (!empty($useVerticalMenu)) $this->gEnv->setCurrentWidgetJoomlaParam(array('moduleclass_sfx' => 'art-vmenu'));
@@ -137,9 +163,24 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 			$this->gEnv->setJoomlaMenuData($this->menuData);
 			
 			// Bootstrap用のデータを埋め込む
-			if ($this->renderType == 'BOOTSTRAP'){
+			if ($this->renderType == 'BOOTSTRAP_NAV'){
 				$this->tmpl->addVar("_widget", "site_url", $this->convertUrlToHtmlEntity($this->gEnv->getRootUrl() . '/'));
 				$this->tmpl->addVar("_widget", "sitename", $this->convertToDispString($this->gEnv->getSiteName()));
+
+				// サイト名の表示制御
+				if (!$showSitename){
+					$sitenameOptionClass = ' visible-xs';			// モニタが最小サイズの場合のみ表示
+					$this->tmpl->addVar("_widget", "sitename_option_class", $sitenameOptionClass);
+				}
+				// 検索フィールド表示制御
+				if ($showSearch){
+					$this->tmpl->setAttribute('show_search', 'visibility', 'visible');
+				}
+				// 別の色を指定の場合
+				if ($anotherColor){
+					$navbarOptionClass = ' navbar-inverse';
+					$this->tmpl->addVar("_widget", "navbar_option_class", $navbarOptionClass);
+				}
 			}
 		} else {
 			// 出力抑止
@@ -313,11 +354,17 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 							array_unshift($classArray, 'parent');
 							
 							// ##### タグ作成 #####
-							if ($this->renderType == 'BOOTSTRAP'){// Bootstrapタイプのとき
-								$classArray[] = 'dropdown';
+							if ($this->renderType == 'BOOTSTRAP_NAV'){// Bootstrapナビゲーションメニューのとき
+								//$classArray[] = 'dropdown';
+								$dropDownCaret = '';
+								if ($level == 0){
+									$dropDownCaret = ' <b class="caret"></b>';
+								} else {
+									$classArray[] = 'dropdown-submenu';
+								}
 								
 								if (count($classArray) > 0) $attr .= ' class="' . implode(' ', $classArray) . '"';
-								$treeHtml .= '<li' . $attr . '><a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" class="dropdown-toggle" data-toggle="dropdown"><span>' . $title . ' <b class="caret"></b></span></a>' . M3_NL;
+								$treeHtml .= '<li' . $attr . '><a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" class="dropdown-toggle" data-toggle="dropdown"><span>' . $title . $dropDownCaret . '</span></a>' . M3_NL;
 								if (!empty($menuText)){
 									$treeHtml .= '<ul class="dropdown-menu">' . M3_NL;
 									$treeHtml .= $menuText;
@@ -349,7 +396,7 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 						$this->menuTree[] = $menuItem;
 						
 						// ##### タグ作成 #####
-						if ($this->renderType == 'BOOTSTRAP'){// Bootstrapタイプのとき
+						if ($this->renderType == 'BOOTSTRAP_NAV' || $this->renderType == 'BOOTSTRAP'){// Bootstrapメニューのとき
 							$treeHtml .= '<li class="divider"></li>' . M3_NL;
 						} else {
 							$treeHtml .= '<li><span class="separator">' . $title . '</span></li>' . M3_NL;
