@@ -201,7 +201,7 @@ $_msg_symbol      = 'Symbols';
 $_msg_other       = 'Others';
 $_msg_help        = 'View Text Formatting Rules';
 $_msg_week        = array('Sun','Mon','Tue','Wed','Thu','Fri','Sat');
-$_msg_content_back_to_top = '<div class="jumpmenu"><a href="#navigator">&uarr;</a></div>';
+$_msg_content_back_to_top = '<div class="jumpmenu"><a href="#wiki_top">&uarr;</a></div>';
 $_msg_word        = 'These search terms have been highlighted:';
 
 ///////////////////////////////////////
@@ -303,6 +303,7 @@ $_attach_messages = array(
 	'msg_listpage' => 'File already exists in  $1',
 	'msg_listall'  => 'Attached file list of all pages',
 	'msg_file'     => 'Attach file',
+	'msg_select_file'     => 'Select file',
 	'msg_maxsize'  => 'Maximum file size is %s.',
 	'msg_count'    => ' <span class="small">%s download</span>',
 	'msg_password' => 'password',
