@@ -203,7 +203,7 @@ $_msg_symbol         = '記号';
 $_msg_other          = '日本語';
 $_msg_help           = 'テキスト整形のルールを表示する';
 $_msg_week           = array('日','月','火','水','木','金','土');
-$_msg_content_back_to_top = '<div class="jumpmenu"><a href="#navigator">&uarr;</a></div>';
+$_msg_content_back_to_top = '<div class="jumpmenu"><a href="#wiki_top">&uarr;</a></div>';
 $_msg_word           = 'これらのキーワードがハイライトされています：';
 
 ///////////////////////////////////////
@@ -285,7 +285,7 @@ $_msg_add   = 'ページへの追加は、現在のページ内容に改行が
 // article.inc.php
 $_btn_name    = 'お名前';
 $_btn_article = '記事の投稿';
-$_btn_subject = '題名: ';
+$_btn_subject = '　題名: ';
 $_msg_article_mail_sender = '投稿者: ';
 $_msg_article_mail_page   = '投稿先: ';
 
@@ -305,6 +305,7 @@ $_attach_messages = array(
 	'msg_listpage' => '$1 の添付ファイル一覧',
 	'msg_listall'  => '全ページの添付ファイル一覧',
 	'msg_file'     => '添付ファイル',
+	'msg_select_file'     => 'ファイル選択',
 	'msg_maxsize'  => 'アップロード可能最大ファイルサイズは %s です。',
 	'msg_count'    => ' <span class="small">%s件</span>',
 	'msg_password' => 'パスワード',
@@ -531,12 +532,12 @@ $_rename_messages  = array(
 // search.inc.php
 $_title_search  = '単語検索';
 $_title_result  = '$1 の検索結果';
-$_msg_searching = '全てのページから単語を検索します。大文字小文字の区別はありません。';
+$_msg_searching = 'すべてのページから単語を検索します。大文字小文字の区別はありません。';
 $_btn_search    = '検索';
 $_btn_and       = 'AND検索';
 $_btn_or        = 'OR検索';
 $_search_pages  = '$1 から始まるページを検索';
-$_search_all    = '全てのページを検索';
+$_search_all    = 'すべてのページを検索';
 
 ///////////////////////////////////////
 // source.inc.php
