@@ -308,9 +308,9 @@ function make_heading(& $str, $strip = TRUE)
 	}
 
 	// Cut footnotes and tags
-	if ($strip === TRUE)
-		$str = strip_htmltag(make_link(preg_replace($NotePattern, '', $str)));
-
+//	if ($strip === TRUE) $str = strip_htmltag(make_link(preg_replace($NotePattern, '', $str)));
+	if ($strip === TRUE) $str = strip_htmltag(make_link(preg_replace_callback($NotePattern, create_function('$matches','return;'), $str)));		// PHP5.5用修正
+	
 	return $id;
 }
 
