@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2014 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id: attach.inc.php 3474 2010-08-13 10:36:48Z fishbone $
  * @link       http://www.magic3.org
@@ -90,7 +90,7 @@ function plugin_attach_action()
 {
 	//global $vars, $_attach_messages;
 	global $_attach_messages;
-
+	
 	// Backward compatible
 	/*if (isset($vars['openfile'])) {
 		$vars['file'] = $vars['openfile'];
@@ -442,17 +442,32 @@ function attach_form($page)
 {
 	//global $script, $vars, $_attach_messages;
 	global $script, $_attach_messages;
+	global $gEnvManager;
 
+	// テンプレートタイプに合わせて出力を変更
+	$templateType = $gEnvManager->getCurrentTemplateType();
+	
 	$r_page = rawurlencode($page);
 	$s_page = htmlspecialchars($page);
 	$linkList		= $script. WikiParam::convQuery("?plugin=attach&amp;pcmd=list&amp;refer=$r_page");
 	$linkListAll	= $script. WikiParam::convQuery("?plugin=attach&amp;pcmd=list");
-	$navi = <<<EOD
+	
+	// テンプレートタイプに合わせて出力を変更
+	if ($templateType == M3_TEMPLATE_BOOTSTRAP_30){		// Bootstrap型テンプレートの場合
+		$navi = <<<EOD
+  <p>
+   [<a href="$linkList">{$_attach_messages['msg_list']}</a>]
+   [<a href="$linkListAll">{$_attach_messages['msg_listall']}</a>]
+  </p>
+EOD;
+	} else {
+		$navi = <<<EOD
   <span class="small">
    [<a href="$linkList">{$_attach_messages['msg_list']}</a>]
    [<a href="$linkListAll">{$_attach_messages['msg_listall']}</a>]
   </span><br />
 EOD;
+	}
 /*
 	$navi = <<<EOD
   <span class="small">
@@ -472,11 +487,45 @@ EOD;*/
 	//if (PLUGIN_ATTACH_PASSWORD_REQUIRE || PLUGIN_ATTACH_UPLOAD_ADMIN_ONLY) {
 	if (PLUGIN_ATTACH_UPLOAD_ADMIN_ONLY) {
 		$title = $_attach_messages[PLUGIN_ATTACH_UPLOAD_ADMIN_ONLY ? 'msg_adminpass' : 'msg_password'];
-		$pass = '<br />' . $title . ': <input type="password" name="password" size="12" />';
+		
+		// テンプレートタイプに合わせて出力を変更
+		if ($templateType == M3_TEMPLATE_BOOTSTRAP_30){		// Bootstrap型テンプレートの場合
+			$pass = '<div class="form-group"><label for="_p_attach_password">' . $title . ':' . '</label> <input type="password" class="form-control" id="_p_attach_password" name="password" size="12" /></div>';
+		} else {
+			$pass = '<br />' . $title . ': <input type="password" name="password" size="12" />';
+		}
 		$hiddenPath = '<input type="hidden" name="pass" />';
 	}
 	$postScript = $script . WikiParam::convQuery("?");
-	$retValue = <<<EOD
+	
+	// テンプレートタイプに合わせて出力を変更
+	if ($templateType == M3_TEMPLATE_BOOTSTRAP_30){		// Bootstrap型テンプレートの場合
+		$retValue = <<<EOD
+<form enctype="multipart/form-data" action="$postScript" method="post" class="form form-inline" role="form">
+  <input type="hidden" name="plugin" value="attach" />
+  <input type="hidden" name="pcmd"   value="post" />
+  <input type="hidden" name="refer"  value="$s_page" />
+  <input type="hidden" name="max_file_size" value="$maxsize" />
+  $hiddenPath
+  $navi
+  <p>
+   $msg_maxsize
+  </p>
+  <div class="form-group">
+    <div class="input-group">
+      <span class="input-group-btn">
+        <span class="btn btn-primary btn-file">{$_attach_messages['msg_select_file']}<input type="file" name="attach_file"></span>
+      </span>
+      <input type="text" class="form-control" readonly>
+    </div>
+  </div>
+  <div>$pass
+  <input type="submit" class="button btn btn-default" value="{$_attach_messages['btn_upload']}" onclick="this.form.pass.value = hex_md5(this.form.password.value);" />
+  </div>
+</form>
+EOD;
+	} else {
+		$retValue = <<<EOD
 <form enctype="multipart/form-data" action="$postScript" method="post" class="form">
  <div>
   <input type="hidden" name="plugin" value="attach" />
@@ -494,6 +543,7 @@ EOD;*/
  </div>
 </form>
 EOD;
+	}
 	return $retValue;
 }
 
@@ -614,6 +664,7 @@ class AttachFile
 	function toString($showicon, $showinfo)
 	{
 		global $script, $_attach_messages;
+		global $gEnvManager;
 
 		$this->getstatus();
 		$param  = '&amp;file=' . rawurlencode($this->file) . '&amp;refer=' . rawurlencode($this->page) .
@@ -627,64 +678,111 @@ class AttachFile
 		$infoUrl = $script . WikiParam::convQuery("?plugin=attach&amp;pcmd=info$param");
 		$openUrl = $script . WikiParam::convQuery("?plugin=attach&amp;pcmd=open$param");
 		if ($showinfo) {
-			$_title = str_replace('$1', rawurlencode($this->file), $_attach_messages['msg_info']);
-			$info = "\n<span class=\"small\">[<a href=\"$infoUrl\" title=\"$_title\">{$_attach_messages['btn_info']}</a>]</span>\n";
-			$count = ($showicon && ! empty($this->status['count'][$this->age])) ?
-				sprintf($_attach_messages['msg_count'], $this->status['count'][$this->age]) : '';
+			// テンプレートタイプに合わせて出力を変更
+			$templateType = $gEnvManager->getCurrentTemplateType();
+			if ($templateType == M3_TEMPLATE_BOOTSTRAP_30){		// Bootstrap型テンプレートの場合
+				$_title = str_replace('$1', rawurlencode($this->file), $_attach_messages['msg_info']);
+				$info = "\n[<a href=\"$infoUrl\" title=\"$_title\">{$_attach_messages['btn_info']}</a>]\n";
+				$count = ($showicon && ! empty($this->status['count'][$this->age])) ?
+					sprintf($_attach_messages['msg_count'], $this->status['count'][$this->age]) : '';
+			} else {
+				$_title = str_replace('$1', rawurlencode($this->file), $_attach_messages['msg_info']);
+				$info = "\n<span class=\"small\">[<a href=\"$infoUrl\" title=\"$_title\">{$_attach_messages['btn_info']}</a>]</span>\n";
+				$count = ($showicon && ! empty($this->status['count'][$this->age])) ?
+					sprintf($_attach_messages['msg_count'], $this->status['count'][$this->age]) : '';
+			}
 		}
-		return "<a href=\"$openUrl\" title=\"$title\">$label</a>$count$info";
-		/*if ($showinfo) {
-			$_title = str_replace('$1', rawurlencode($this->file), $_attach_messages['msg_info']);
-			$info = "\n<span class=\"small\">[<a href=\"$script?plugin=attach&amp;pcmd=info$param\" title=\"$_title\">{$_attach_messages['btn_info']}</a>]</span>\n";
-			$count = ($showicon && ! empty($this->status['count'][$this->age])) ?
-				sprintf($_attach_messages['msg_count'], $this->status['count'][$this->age]) : '';
-		}
-		return "<a href=\"$script?plugin=attach&amp;pcmd=open$param\" title=\"$title\">$label</a>$count$info";*/
+//		return "<a href=\"$openUrl\" title=\"$title\">$label</a>$count$info";
+		return "<a href=\"$openUrl\" title=\"$title\" target=\"_blank\">$label</a>$count$info";
 	}
 
 	// 情報表示
 	function info($err)
 	{
 		global $script, $_attach_messages;
+		global $gEnvManager;
 
+		// テンプレートタイプに合わせて出力を変更
+		$templateType = $gEnvManager->getCurrentTemplateType();
+		
 		$r_page = rawurlencode($this->page);
 		$s_page = htmlspecialchars($this->page);
 		$s_file = htmlspecialchars($this->file);
 		$s_err = ($err == '') ? '' : '<p style="font-weight:bold">' . $_attach_messages[$err] . '</p>';
 
 		$msg_rename  = '';
-		if ($this->age) {
-			$msg_freezed = '';
-			$msg_delete  = '<input type="radio" name="pcmd" id="_p_attach_delete" value="delete" />' .
-				'<label for="_p_attach_delete">' .  $_attach_messages['msg_delete'] .
-				$_attach_messages['msg_require'] . '</label><br />';
-			$msg_freeze  = '';
-		} else {
-			if ($this->status['freeze']) {
-				$msg_freezed = "<dd>{$_attach_messages['msg_isfreeze']}</dd>";
-				$msg_delete  = '';
-				$msg_freeze  = '<input type="radio" name="pcmd" id="_p_attach_unfreeze" value="unfreeze" />' .
-					'<label for="_p_attach_unfreeze">' .  $_attach_messages['msg_unfreeze'] .
-					$_attach_messages['msg_require'] . '</label><br />';
-			} else {
-				$msg_freezed = '';
-				$msg_delete = '<input type="radio" name="pcmd" id="_p_attach_delete" value="delete" />' .
-					'<label for="_p_attach_delete">' . $_attach_messages['msg_delete'];
-				if (PLUGIN_ATTACH_DELETE_ADMIN_ONLY || $this->age)
-					$msg_delete .= $_attach_messages['msg_require'];
-				$msg_delete .= '</label><br />';
-				$msg_freeze  = '<input type="radio" name="pcmd" id="_p_attach_freeze" value="freeze" />' .
-					'<label for="_p_attach_freeze">' .  $_attach_messages['msg_freeze'] .
-					$_attach_messages['msg_require'] . '</label><br />';
 
-				if (PLUGIN_ATTACH_RENAME_ENABLE) {
-					$msg_rename  = '<input type="radio" name="pcmd" id="_p_attach_rename" value="rename" />' .
-						'<label for="_p_attach_rename">' .  $_attach_messages['msg_rename'] .
-						$_attach_messages['msg_require'] . '</label><br />&nbsp;&nbsp;&nbsp;&nbsp;' .
-						'<label for="_p_attach_newname">' . $_attach_messages['msg_newname'] .
-						':</label> ' .
-						'<input type="text" name="newname" id="_p_attach_newname" size="40" value="' .
-						$this->file . '" /><br />';
+		// テンプレートタイプに合わせて出力を変更
+		if ($templateType == M3_TEMPLATE_BOOTSTRAP_30){		// Bootstrap型テンプレートの場合
+			if ($this->age) {
+				$msg_freezed = '';
+				$msg_delete  = '<div><div class="radio"><input type="radio" name="pcmd" id="_p_attach_delete" value="delete" />' .
+					'<label for="_p_attach_delete">' .  $_attach_messages['msg_delete'] .
+					$_attach_messages['msg_require'] . '</label></div></div>';
+				$msg_freeze  = '';
+			} else {
+				if ($this->status['freeze']) {
+					$msg_freezed = "<dd>{$_attach_messages['msg_isfreeze']}</dd>";
+					$msg_delete  = '';
+					$msg_freeze  = '<div><div class="radio"><input type="radio" name="pcmd" id="_p_attach_unfreeze" value="unfreeze" />' .
+						'<label for="_p_attach_unfreeze">' .  $_attach_messages['msg_unfreeze'] .
+						$_attach_messages['msg_require'] . '</label></div></div>';
+				} else {
+					$msg_freezed = '';
+					$msg_delete = '<div><div class="radio"><input type="radio" name="pcmd" id="_p_attach_delete" value="delete" />' .
+						'<label for="_p_attach_delete">' . $_attach_messages['msg_delete'];
+					if (PLUGIN_ATTACH_DELETE_ADMIN_ONLY || $this->age)
+						$msg_delete .= $_attach_messages['msg_require'];
+					$msg_delete .= '</label></div></div>';
+					$msg_freeze  = '<div><div class="radio"><input type="radio" name="pcmd" id="_p_attach_freeze" value="freeze" />' .
+						'<label for="_p_attach_freeze">' .  $_attach_messages['msg_freeze'] .
+						$_attach_messages['msg_require'] . '</label></div></div>';
+
+					if (PLUGIN_ATTACH_RENAME_ENABLE) {
+						$msg_rename  = '<div><div class="radio"><input type="radio" name="pcmd" id="_p_attach_rename" value="rename" />' .
+							'<label for="_p_attach_rename">' .  $_attach_messages['msg_rename'] .
+							$_attach_messages['msg_require'] . '</label></div></div>' .
+							'<div class="form-group"><label for="_p_attach_newname">' . $_attach_messages['msg_newname'] .
+							':</label> ' .
+							'<input type="text" name="newname" id="_p_attach_newname" class="form-control" size="40" value="' .
+							$this->file . '" /></div>';
+					}
+				}
+			}
+		} else {
+			if ($this->age) {
+				$msg_freezed = '';
+				$msg_delete  = '<input type="radio" name="pcmd" id="_p_attach_delete" value="delete" />' .
+					'<label for="_p_attach_delete">' .  $_attach_messages['msg_delete'] .
+					$_attach_messages['msg_require'] . '</label><br />';
+				$msg_freeze  = '';
+			} else {
+				if ($this->status['freeze']) {
+					$msg_freezed = "<dd>{$_attach_messages['msg_isfreeze']}</dd>";
+					$msg_delete  = '';
+					$msg_freeze  = '<input type="radio" name="pcmd" id="_p_attach_unfreeze" value="unfreeze" />' .
+						'<label for="_p_attach_unfreeze">' .  $_attach_messages['msg_unfreeze'] .
+						$_attach_messages['msg_require'] . '</label><br />';
+				} else {
+					$msg_freezed = '';
+					$msg_delete = '<input type="radio" name="pcmd" id="_p_attach_delete" value="delete" />' .
+						'<label for="_p_attach_delete">' . $_attach_messages['msg_delete'];
+					if (PLUGIN_ATTACH_DELETE_ADMIN_ONLY || $this->age)
+						$msg_delete .= $_attach_messages['msg_require'];
+					$msg_delete .= '</label><br />';
+					$msg_freeze  = '<input type="radio" name="pcmd" id="_p_attach_freeze" value="freeze" />' .
+						'<label for="_p_attach_freeze">' .  $_attach_messages['msg_freeze'] .
+						$_attach_messages['msg_require'] . '</label><br />';
+
+					if (PLUGIN_ATTACH_RENAME_ENABLE) {
+						$msg_rename  = '<input type="radio" name="pcmd" id="_p_attach_rename" value="rename" />' .
+							'<label for="_p_attach_rename">' .  $_attach_messages['msg_rename'] .
+							$_attach_messages['msg_require'] . '</label><br />&nbsp;&nbsp;&nbsp;&nbsp;' .
+							'<label for="_p_attach_newname">' . $_attach_messages['msg_newname'] .
+							':</label> ' .
+							'<input type="text" name="newname" id="_p_attach_newname" size="40" value="' .
+							$this->file . '" /><br />';
+					}
 				}
 			}
 		}
@@ -693,21 +791,59 @@ class AttachFile
 		$postScript 	= $script . WikiParam::convQuery("?");
 		$linkList		= $script . WikiParam::convQuery("?plugin=attach&amp;pcmd=list&amp;refer=$r_page");
 		$linkListAll	= $script . WikiParam::convQuery("?plugin=attach&amp;pcmd=list");
-		$retval = array('msg'=>sprintf($_attach_messages['msg_info'], htmlspecialchars($this->file)));
-		$retval['body'] = <<< EOD
+		$retval			= array('msg'=>sprintf($_attach_messages['msg_info'], htmlspecialchars($this->file)));
+		$filename		= basename($this->filename);
+		
+		// テンプレートタイプに合わせて出力を変更
+		if ($templateType == M3_TEMPLATE_BOOTSTRAP_30){		// Bootstrap型テンプレートの場合
+			$retval['body'] = <<< EOD
+<p>
+ [<a href="$linkList">{$_attach_messages['msg_list']}</a>]
+ [<a href="$linkListAll">{$_attach_messages['msg_listall']}</a>]
+</p>
+<dl class="wiki_list">
+ <dt>$info</dt>
+ <dd>{$_attach_messages['msg_page']}: $s_page</dd>
+ <dd>{$_attach_messages['msg_filename']}: {$filename}</dd>
+ <dd>{$_attach_messages['msg_md5hash']}: {$this->md5hash}</dd>
+ <dd>{$_attach_messages['msg_filesize']}: {$this->size_str} ({$this->size} bytes)</dd>
+ <dd>Content-type: {$this->type}</dd>
+ <dd>{$_attach_messages['msg_date']}: {$this->time_str}</dd>
+ <dd>{$_attach_messages['msg_dlcount']}: {$this->status['count'][$this->age]}</dd>
+ $msg_freezed
+</dl>
+<hr />
+$s_err
+<form action="$postScript" method="post" class="form form-inline" role="form">
+  <input type="hidden" name="plugin" value="attach" />
+  <input type="hidden" name="refer" value="$s_page" />
+  <input type="hidden" name="file" value="$s_file" />
+  <input type="hidden" name="age" value="{$this->age}" />
+  <input type="hidden" name="pass" />
+  $msg_delete
+  $msg_freeze
+  $msg_rename
+  <br /><br />
+  <div class="form-group"><label for="_p_attach_password">{$_attach_messages['msg_password']}:</label>
+  <input type="password" name="password" id="_p_attach_password" class="form-control" size="12" /></div>
+  <input type="submit" class="button btn btn-default" value="{$_attach_messages['btn_submit']}" onclick="this.form.pass.value = hex_md5(this.form.password.value);" />
+</form>
+EOD;
+		} else {
+			$retval['body'] = <<< EOD
 <p class="small">
  [<a href="$linkList">{$_attach_messages['msg_list']}</a>]
  [<a href="$linkListAll">{$_attach_messages['msg_listall']}</a>]
 </p>
 <dl class="wiki_list">
  <dt>$info</dt>
- <dd>{$_attach_messages['msg_page']}:$s_page</dd>
- <dd>{$_attach_messages['msg_filename']}:{$this->filename}</dd>
- <dd>{$_attach_messages['msg_md5hash']}:{$this->md5hash}</dd>
- <dd>{$_attach_messages['msg_filesize']}:{$this->size_str} ({$this->size} bytes)</dd>
- <dd>Content-type:{$this->type}</dd>
- <dd>{$_attach_messages['msg_date']}:{$this->time_str}</dd>
- <dd>{$_attach_messages['msg_dlcount']}:{$this->status['count'][$this->age]}</dd>
+ <dd>{$_attach_messages['msg_page']}: $s_page</dd>
+ <dd>{$_attach_messages['msg_filename']}: {$filename}</dd>
+ <dd>{$_attach_messages['msg_md5hash']}: {$this->md5hash}</dd>
+ <dd>{$_attach_messages['msg_filesize']}: {$this->size_str} ({$this->size} bytes)</dd>
+ <dd>Content-type: {$this->type}</dd>
+ <dd>{$_attach_messages['msg_date']}: {$this->time_str}</dd>
+ <dd>{$_attach_messages['msg_dlcount']}: {$this->status['count'][$this->age]}</dd>
  $msg_freezed
 </dl>
 <hr />
@@ -729,6 +865,7 @@ $s_err
  </div>
 </form>
 EOD;
+		}
 		return $retval;
 	}
 
