@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2014 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id: freeze.inc.php 1601 2009-03-21 05:51:06Z fishbone $
  * @link       http://www.magic3.org
@@ -23,7 +23,8 @@ function plugin_freeze_action()
 	global $script, $function_freeze;
 	global $_title_isfreezed, $_title_freezed, $_title_freeze;
 	global $_msg_invalidpass, $_msg_freezing, $_btn_freeze;
-
+	global $gEnvManager;
+	
 	//$page = isset($vars['page']) ? $vars['page'] : '';
 	$page = WikiParam::getPage();
 	if (! $function_freeze || ! is_page($page))
@@ -62,7 +63,22 @@ function plugin_freeze_action()
 		$body   = ($pass == '') ? '' : "<p><strong>$_msg_invalidpass</strong></p>\n";
 		// modified for Magic3 by naoki on 2008/10/6
 		$postScript = $script . WikiParam::convQuery("?");
-		$body  .= <<<EOD
+		
+		// テンプレートタイプに合わせて出力を変更
+		$templateType = $gEnvManager->getCurrentTemplateType();
+		if ($templateType == M3_TEMPLATE_BOOTSTRAP_30){		// Bootstrap型テンプレートの場合
+			$body  .= <<<EOD
+<p>$_msg_freezing</p>
+<form action="$postScript" method="post" class="form form-inline" role="form">
+  <input type="hidden"   name="wcmd"  value="freeze" />
+  <input type="hidden"   name="page" value="$s_page" />
+  <input type="hidden"   name="pass" />
+  <div class="form-group"><input type="password" class="form-control" name="password" size="12" /></div>
+  <input type="submit"   name="ok"   class="button btn btn-default" value="$_btn_freeze" onclick="this.form.pass.value = hex_md5(this.form.password.value);" />
+</form>
+EOD;
+		} else {
+			$body  .= <<<EOD
 <p>$_msg_freezing</p>
 <form action="$postScript" method="post" class="form">
  <div>
@@ -74,6 +90,7 @@ function plugin_freeze_action()
  </div>
 </form>
 EOD;
+		}
 	}
 
 	return array('msg'=>$msg, 'body'=>$body);
