@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2014 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: rename.inc.php 1161 2008-10-30 08:47:27Z fishbone $
+ * @version    SVN: $Id: rename.inc.php 1601 2009-03-21 05:51:06Z fishbone $
  * @link       http://www.magic3.org
  */
 //
@@ -100,7 +100,8 @@ function plugin_rename_err($err, $page = '')
 function plugin_rename_phase1($err = '', $page = '')
 {
 	global $script, $_rename_messages;
-
+	global $gEnvManager;
+	
 	$msg    = plugin_rename_err($err, $page);
 	$refer  = plugin_rename_getvar('refer');
 	$method = plugin_rename_getvar('method');
@@ -119,10 +120,13 @@ function plugin_rename_phase1($err = '', $page = '')
 	$postScript = $script . WikiParam::convQuery("?");
 	$ret = array();
 	$ret['msg']  = $_rename_messages['msg_title'];
-/*	$ret['body'] = <<<EOD
+
+	// テンプレートタイプに合わせて出力を変更
+	$templateType = $gEnvManager->getCurrentTemplateType();
+	if ($templateType == M3_TEMPLATE_BOOTSTRAP_30){		// Bootstrap型テンプレートの場合
+		$ret['body'] = <<<EOD
 $msg
-<form action="$script" method="post">
- <div>
+<form action="$postScript" method="post" class="form form-inline" role="form">
   <input type="hidden" name="plugin" value="rename" />
   <input type="radio"  name="method" id="_p_rename_page" value="page"$radio_page />
   <label for="_p_rename_page">{$_rename_messages['msg_page']}:</label>$select_refer<br />
@@ -132,13 +136,13 @@ $msg
   <input type="text" name="src" id="_p_rename_from" size="80" value="$s_src" /><br />
   <label for="_p_rename_to">To:</label><br />
   <input type="text" name="dst" id="_p_rename_to"   size="80" value="$s_dst" /><br />
-  <input type="submit" value="{$_rename_messages['btn_next']}" /><br />
- </div>
+  <input type="submit" class="button" value="{$_rename_messages['btn_next']}" /><br />
 </form>
-EOD;*/
-	$ret['body'] = <<<EOD
+EOD;
+	} else {
+		$ret['body'] = <<<EOD
 $msg
-<form action="$postScript" method="post">
+<form action="$postScript" method="post" class="form">
  <div>
   <input type="hidden" name="plugin" value="rename" />
   <input type="radio"  name="method" id="_p_rename_page" value="page"$radio_page />
@@ -149,10 +153,11 @@ $msg
   <input type="text" name="src" id="_p_rename_from" size="80" value="$s_src" /><br />
   <label for="_p_rename_to">To:</label><br />
   <input type="text" name="dst" id="_p_rename_to"   size="80" value="$s_dst" /><br />
-  <input type="submit" value="{$_rename_messages['btn_next']}" /><br />
+  <input type="submit" class="button" value="{$_rename_messages['btn_next']}" /><br />
  </div>
 </form>
 EOD;
+	}
 	return $ret;
 }
 
@@ -181,23 +186,10 @@ function plugin_rename_phase2($err = '', $page = '')
 	$postScript = $script . WikiParam::convQuery("?");
 	$ret = array();
 	$ret['msg']  = $_rename_messages['msg_title'];
-/*	$ret['body'] = <<<EOD
-$msg
-<form action="$script" method="post">
- <div>
-  <input type="hidden" name="plugin" value="rename" />
-  <input type="hidden" name="refer"  value="$s_refer" />
-  $msg_rename<br />
-  <label for="_p_rename_newname">{$_rename_messages['msg_newname']}:</label>
-  <input type="text" name="page" id="_p_rename_newname" size="80" value="$s_page" /><br />
-  $msg_related
-  <input type="submit" value="{$_rename_messages['btn_next']}" /><br />
- </div>
-</form>
-EOD;*/
+
 	$ret['body'] = <<<EOD
 $msg
-<form action="$postScript" method="post">
+<form action="$postScript" method="post" class="form">
  <div>
   <input type="hidden" name="plugin" value="rename" />
   <input type="hidden" name="refer"  value="$s_refer" />
@@ -205,7 +197,7 @@ $msg
   <label for="_p_rename_newname">{$_rename_messages['msg_newname']}:</label>
   <input type="text" name="page" id="_p_rename_newname" size="80" value="$s_page" /><br />
   $msg_related
-  <input type="submit" value="{$_rename_messages['btn_next']}" /><br />
+  <input type="submit" class="button" value="{$_rename_messages['btn_next']}" /><br />
  </div>
 </form>
 EOD;
@@ -334,29 +326,17 @@ function plugin_rename_phase3($pages)
 	$postScript = $script . WikiParam::convQuery("?");
 	$ret = array();
 	$ret['msg'] = $_rename_messages['msg_title'];
-/*	$ret['body'] = <<<EOD
-<p>$msg</p>
-<form action="$script" method="post">
- <div>
-  <input type="hidden" name="plugin" value="rename" />
-  $input
-  <label for="_p_rename_adminpass">{$_rename_messages['msg_adminpass']}</label>
-  <input type="password" name="pass" id="_p_rename_adminpass" value="" />
-  <input type="submit" value="{$_rename_messages['btn_submit']}" />
- </div>
-</form>
-<p>{$_rename_messages['msg_confirm']}</p>
-EOD;*/
+
 	$ret['body'] = <<<EOD
 <p>$msg</p>
-<form action="$postScript" method="post">
+<form action="$postScript" method="post" class="form">
  <div>
   <input type="hidden" name="plugin" value="rename" />
   <input type="hidden" name="pass" />
   $input
   <label for="_p_rename_adminpass">{$_rename_messages['msg_adminpass']}</label>
   <input type="password" name="password" id="_p_rename_adminpass" size="12" />
-  <input type="submit" value="{$_rename_messages['btn_submit']}" onclick="this.form.pass.value = hex_md5(this.form.password.value);" />
+  <input type="submit" class="button" value="{$_rename_messages['btn_submit']}" onclick="this.form.pass.value = hex_md5(this.form.password.value);" />
  </div>
 </form>
 <p>{$_rename_messages['msg_confirm']}</p>
